"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeChains = makeChains;

var _lodash = _interopRequireDefault(require("lodash"));

var _orthos = require("orthos");

var _mutables = require("./mutables");

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var log = console.log;

var d = require('debug')('app');

var asps = _lodash["default"].values(_utils.aspirations);

var augs = ['ἀ', 'ἐ', 'ἠ', 'εἰ', 'ἑ', 'ἰ', 'ὠ', 'ἁ', 'ἡ', 'αἰ', 'αἱ', 'εἱ', 'εὐ', 'αὐ', 'ηὐ', 'εὑ', 'ηὑ', 'ἱ', 'ὀ', 'οἰ', 'ω', 'ὁ', 'ὡ', 'ὑ'];
var augplains = ['α', 'ε', 'η', 'ει', 'ι', 'ω', 'αι', 'ευ', 'αυ', 'ηυ', 'ο', 'οι', 'υ'];

function makeChains(sgms, dicts, flexes, compound, only) {
  var chains = [];

  var prefs = _lodash["default"].filter(dicts, function (dict) {
    return dict.pref;
  });

  var vsufs = _lodash["default"].filter(dicts, function (dict) {
    return dict.suf && dict.stem == 'verb';
  });

  var muts = _lodash["default"].filter(dicts, function (dict) {
    return !dict.suf && !dict.pref;
  }); //  && !dict.irreg с irreg - разобраться
  // let irregs = _.filter(dicts, dict=> { return dict.verb && dict.irreg }) // пока только verb


  var longs = _lodash["default"].filter(muts, function (dict) {
    return dict.plain.length > 1;
  });

  var lplains = _lodash["default"].uniq(muts.map(function (dict) {
    return dict.plain;
  }));

  var flexterms = flexes.map(function (flex) {
    return flex.term;
  });
  sgms = _lodash["default"].filter(sgms, function (segs) {
    return flexterms.includes(_lodash["default"].last(segs));
  });
  d('SGMS', sgms.length);

  var singles = _lodash["default"].filter(sgms, function (segs) {
    return segs.length == 2;
  });

  d('SINGLES', singles.length); // log('__________________________________________make chain singles:', singles.length, 'muts:', muts.length)
  // simple w/o aug

  singles.forEach(function (segs) {
    if (compound) return;
    var mainseg = (0, _orthos.plain)(segs[0]);
    muts = _lodash["default"].filter(muts, function (dict) {
      return !dict.compound;
    }); // let verbs = _.filter(muts, dict=> { return dict.verb })
    // let names = _.filter(muts, dict=> { return dict.name })
    // // здесь есть irregs, но нужно отбросить compound:
    // let maindicts = _.filter(names, dict=> { return dict.plain == mainseg })
    // let verbdicts = _.filter(verbs, dict=> { return !dict.aug && dict.plain == mainseg && !dict.augs })
    // maindicts.push(...verbdicts)

    var maindicts = _lodash["default"].filter(muts, function (dict) {
      return !dict.aug && dict.plain == mainseg;
    });

    if (!maindicts.length) return; // log('______________single maindicts w/o aug:', segs, mainseg, muts.length, maindicts.length)

    var flexseg = segs[1];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    });

    if (!segflexes.length) return; // log('______________single flexes:', flexseg, segflexes.length)

    var cdicts = makeDictFlex(maindicts, segflexes, only);
    if (!cdicts.length) return;
    var commonseg = [mainseg, flexseg].join('');
    var rdict = {
      seg: commonseg,
      dicts: cdicts,
      cogns: maindicts,
      simple: true,
      stem: mainseg,
      flex: flexseg
    };
    var chain = [rdict];
    chains.push(chain);
  }); // irregs не имеют aug
  // if (chains.length) return chains
  // return chains

  var doubles = _lodash["default"].filter(sgms, function (segs) {
    return segs.length == 3;
  });

  d('DOUBLES', doubles.length); // simple + aug

  doubles.forEach(function (segs) {
    if (compound) return;

    var verbs = _lodash["default"].filter(muts, function (dict) {
      return dict.verb && dict.aug;
    });

    var augseg = (0, _orthos.plain)(segs[0]);
    if (!augs.includes(augseg)) return; // log('____aug-verb augseg:', segs, augseg, verbs.length)

    verbs = _lodash["default"].filter(verbs, function (dict) {
      return dict.aug == augseg;
    });
    if (!verbs.length) return;
    var verbseg = (0, _orthos.plain)(segs[1]);

    var verbdicts = _lodash["default"].filter(verbs, function (dict) {
      return dict.aug && dict.verb && dict.plain == verbseg;
    });

    if (!verbdicts.length) return; // log('__aug-verb: verbseg:', segs, augseg, verbseg, 'verbdicts:', verbdicts.length)

    var flexseg = segs[2];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    });

    if (!segflexes.length) return;
    var cdicts = makeDictFlex(verbdicts, segflexes, only); // log('__aug-verbs:', segs, verbseg, 'verbdicts:', verbdicts.length, 'cdicts:', cdicts.length)

    cdicts = _lodash["default"].filter(cdicts, function (dict) {
      return dict.aug == augseg;
    });
    if (!cdicts.length) return;
    var commonseg = [augseg, verbseg, flexseg].join('');
    var verbsec = {
      seg: commonseg,
      dicts: cdicts,
      cogns: verbdicts,
      simple: true,
      aug: augseg,
      stem: verbseg,
      flex: flexseg
    };
    var chain = [verbsec];
    chains.push(chain);
  });
  if (chains.length) return chains; // === COMPOUNDS ===

  muts = _lodash["default"].filter(muts, function (dict) {
    return dict.plain.length > 1;
  }); // only longs
  // ex: παραστατικός
  // PREF-MUTS

  doubles.forEach(function (segs) {
    var prefseg = (0, _orthos.plain)(segs[0]);

    var prefdicts = _lodash["default"].filter(prefs, function (dict) {
      return dict.plain == prefseg;
    });

    if (!prefdicts.length) return; // log('____pref-muts prefdicts:', segs, prefseg, prefdicts.length)

    var mainseg = (0, _orthos.plain)(segs[1]);

    var maindicts = _lodash["default"].filter(muts, function (dict) {
      return !dict.aug && dict.plain == mainseg;
    });

    if (!maindicts.length) return; // log('__pref-double: mainseg:', segs, mainseg, 'verbdicts:', maindicts)

    var flexseg = segs[2];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    });

    if (!segflexes.length) return; // log('__pref-double: flex:', segs, mainseg, 'segflexes:', segflexes.length)

    var cdicts = makeDictFlex(maindicts, segflexes, only); // log('__pref-double:', segs, mainseg, 'verbdicts:', maindicts.length, 'cdicts:', cdicts.length)

    if (!cdicts.length) return;
    var prefsec = {
      seg: prefseg,
      dicts: prefdicts,
      doubles: true,
      pref: true
    };
    var commonseg = [mainseg, flexseg].join('');
    var mainsec = {
      seg: commonseg,
      dicts: cdicts,
      cogns: maindicts,
      stem: mainseg,
      flex: flexseg
    };
    var chain = [prefsec, mainsec];
    chains.push(chain);
  }); // VERB-SUFF:

  doubles.forEach(function (segs) {
    return; // log('______________doubles suff:', segs)

    var sufseg = (0, _orthos.plain)(segs[1]);

    var sufdicts = _lodash["default"].filter(vsufs, function (dict) {
      return dict.plain == sufseg;
    }); // if (sufdicts.length) log('______________sufdicts:', segs, sufdicts.length)


    if (!sufdicts.length) return;
    var flexseg = segs[2];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    }); // if (segflexes.length) log('______________segflexes:', segflexes.length)


    var cdicts = makeDictFlex(sufdicts, segflexes, only); // log('______________suff-cdicts:', sufdicts.length, segflexes.length, cdicts.length)

    if (!cdicts.length) return;
    var verbseg = (0, _orthos.plain)(segs[0]);

    var verbs = _lodash["default"].filter(muts, function (dict) {
      return dict.verb;
    });

    var verbdicts = selectMutable(verbseg, verbs); // log('______________suff-verbs:', verbdicts.length)

    if (!verbdicts.length) return;
    var verbsec = {
      seg: verbseg,
      dicts: verbdicts,
      doubles: true
    };
    var commonseg;
    var sufsec = {
      seg: sufseg,
      dicts: cdicts,
      suff: true
    };
    var chain = [verbsec, sufsec];
    chains.push(chain);
  }); // DOUBLES: COMPOUND W/O CNNECTOR:
  // нужен пример w/o, но с глаголом, имеющим aug
  // βαρύτονος - имеет коннектор

  doubles.forEach(function (segs) {
    return; // if (!longs.length) return

    var mainseg = (0, _orthos.plain)(segs[1]);
    var maindicts = selectMutablePlain(mainseg, longs);
    if (!maindicts.length) return; // if (maindicts.length) log('______________doubles compound main:', segs, mainseg, 'muts:', muts.length, 'mutdicts:', maindicts.length)

    var flexseg = segs[2];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    });

    var cdicts = makeDictFlex(maindicts, segflexes, only);
    if (!cdicts.length) return; // log('__doubles dicts w/o cnnector __cdicts__:', segs, mainseg, 'maindicts:', maindicts.length, '_cdicts_:', cdicts.length)

    var firstseg = (0, _orthos.plain)(segs[0]);
    var firstdicts = selectMutable(firstseg, longs); // log('______________doubles compound firstdicts:', segs, mainseg, 'muts:', muts.length, 'firstdicts:', firstdicts.length)

    if (!firstdicts.length) return;
    var firstsec = {
      seg: firstseg,
      dicts: firstdicts,
      doubles: true,
      compound: true
    };
    var commonseg;
    var mainsec = {
      seg: mainseg,
      dicts: cdicts
    };
    var chain = [firstsec, mainsec];
    chains.push(chain);
  });

  var triples = _lodash["default"].filter(sgms, function (segs) {
    return segs.length == 4;
  }); // PREF-MUTS
  // ex: ἀφαιρέω


  triples.forEach(function (segs) {
    var prefseg = (0, _orthos.plain)(segs[0]);

    var prefdicts = _lodash["default"].filter(prefs, function (dict) {
      return dict.plain == prefseg;
    });

    if (!prefdicts.length) return; // log('____pref-verb prefdicts:', segs, prefseg, prefdicts.length)

    var verbs = _lodash["default"].filter(muts, function (dict) {
      return dict.verb && dict.aug;
    });

    var augseg = (0, _orthos.plain)(segs[1]);
    if (!augplains.includes(augseg)) return;
    verbs = _lodash["default"].filter(verbs, function (dict) {
      return (0, _orthos.strip)(dict.aug) == augseg;
    });
    if (!verbs.length) return; // log('____aug-verb augseg:', segs, augseg, verbs.length)

    var verbseg = (0, _orthos.plain)(segs[2]);

    var verbdicts = _lodash["default"].filter(verbs, function (dict) {
      return dict.aug && dict.plain == verbseg;
    });

    if (!verbdicts.length) return; // log('__pref-verb: verbseg:', segs, verbseg, 'verbdicts:', verbdicts.length)

    var flexseg = segs[3];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    });

    if (!segflexes.length) return;
    var cdicts = makeDictFlex(verbdicts, segflexes, only); // log('__pref-verb:', segs, verbseg, 'verbdicts:', verbdicts.length, 'cdicts:', cdicts.length)

    if (!cdicts.length) return;
    var prefsec = {
      seg: prefseg,
      dicts: prefdicts,
      triples: true,
      pref: true
    };
    var commonseg = [augseg, verbseg, flexseg].join('');
    var verbsec = {
      seg: commonseg,
      dicts: cdicts,
      cogns: verbdicts,
      aug: augseg,
      stem: verbseg,
      flex: flexseg
    };
    var chain = [prefsec, verbsec];
    chains.push(chain);
  }); // βαρύτονος - barutonos
  // TRIPLES: COMPOUND WITH CONNECTOR

  triples.forEach(function (segs) {
    var connector;
    var conseg = (0, _orthos.strip)(segs[1]);
    if (conseg.length == 1 && _utils.vowels.includes(conseg)) connector = conseg;
    if (!connector) return; // log('________________________________triples:', segs, 'conn:', connector)

    var firstseg = (0, _orthos.plain)(segs[0]);

    var firstdicts = _lodash["default"].filter(muts, function (dict) {
      return !dict.aug && dict.plain == firstseg;
    });

    if (!firstdicts.length) return; // log('__triples firstseg__:', segs, mainseg, 'maindicts:', maindicts.length, '_cdicts_:', cdicts.length, 'firstdicts:', firstdicts.length)

    var mainseg = (0, _orthos.plain)(segs[2]);

    var maindicts = _lodash["default"].filter(muts, function (dict) {
      return !dict.aug && dict.plain == mainseg;
    });

    if (!maindicts.length) return; // log('__triples mainseg__:', segs, mainseg, 'maindicts:', maindicts.length)

    var flexseg = segs[3];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    });

    if (!segflexes.length) return;
    var cdicts = makeDictFlex(maindicts, segflexes, only);
    if (!cdicts.length) return; // log('__triples mainseg__:', segs, mainseg, 'maindicts:', maindicts.length, '_cdicts_:', cdicts.length)
    // compound with vowel in a middle:

    var firstsec = _defineProperty({
      seg: firstseg,
      dicts: firstdicts,
      stem: firstseg,
      triples: true,
      type: 'comp-connector'
    }, "stem", firstseg);

    var connsec = {
      seg: conseg,
      connector: connector,
      dicts: []
    };
    var commonseg = [mainseg, flexseg].join('');
    var secsec = {
      seg: commonseg,
      dicts: cdicts,
      cogns: maindicts,
      stem: mainseg,
      flex: flexseg
    };
    var chain = [firstsec, connsec, secsec];
    chains.push(chain);
  }); // TRIPLES: TWO PREFS W/O AUG
  // ex: ἐγκαταβιόω, i.e. ἐγκαταβιῶ

  triples.forEach(function (segs) {
    // log('___________________________________________ triple-segs:', segs)
    var prefseg = (0, _orthos.plain)(segs[0]);

    var prefdicts = _lodash["default"].filter(prefs, function (dict) {
      return dict.plain == prefseg;
    });

    if (!prefdicts.length) return; // log('____triples pref-verb prefdicts:', prefseg, prefdicts.length)

    var prefss = prefs.map(function (dict) {
      return dict.plain;
    });
    var prefseg2 = (0, _orthos.strip)(segs[1]);

    var prefdicts2 = _lodash["default"].filter(prefs, function (dict) {
      return (0, _orthos.strip)(dict.plain) == prefseg2;
    });

    if (!prefdicts2.length) return; // log('____triples pref-verb prefdicts2:', prefseg, prefseg2, prefdicts2.length)

    var mainseg = (0, _orthos.plain)(segs[2]);

    var maindicts = _lodash["default"].filter(muts, function (dict) {
      return !dict.aug && dict.plain == mainseg;
    });

    if (!maindicts.length) return;
    var flexseg = segs[3];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    });

    if (!segflexes.length) return;
    var cdicts = makeDictFlex(maindicts, segflexes, only);
    if (!cdicts.length) return; // log('__triples prefs 2 mainseg__:', segs, mainseg, 'maindicts:', maindicts.length, '_cdicts_:', cdicts.length)

    var prefsec = {
      seg: prefseg,
      dicts: prefdicts,
      triples: true,
      pref: true
    };
    var prefsec2 = {
      seg: prefseg2,
      dicts: prefdicts2,
      pref2: true
    };
    var commonseg = [mainseg, flexseg].join('');
    var mainsec = {
      seg: commonseg,
      dicts: cdicts,
      cogns: maindicts,
      stem: mainseg,
      flex: flexseg
    };
    var chain = [prefsec, prefsec2, mainsec];
    chains.push(chain);
  });
  if (chains.length) return chains;

  var quads = _lodash["default"].filter(sgms, function (segs) {
    return segs.length == 5;
  }); // log('QUADS', quads.length)
  // ex: προσδιαιρέω
  // QUADRUPLES: TWO PREFS + AUG


  quads.forEach(function (segs) {
    var prefseg = (0, _orthos.plain)(segs[0]);

    var prefdicts = _lodash["default"].filter(prefs, function (dict) {
      return dict.plain == prefseg;
    }); // log('____quads pref-verb prefdicts:', prefseg, prefdicts.length)


    if (!prefdicts.length) return;
    var prefseg2 = (0, _orthos.strip)(segs[1]);

    var prefdicts2 = _lodash["default"].filter(prefs, function (dict) {
      return (0, _orthos.strip)(dict.plain) == prefseg2;
    });

    if (!prefdicts2.length) return; // log('____quads pref-verb prefdicts2:', prefseg, prefseg2, prefdicts2.length)

    var augseg = (0, _orthos.strip)(segs[2]);
    if (!augplains.includes(augseg)) return; // log('____quads pref-verb augseg:', prefseg, prefseg2, augseg)

    var mainseg = (0, _orthos.plain)(segs[3]);

    var maindicts = _lodash["default"].filter(muts, function (dict) {
      return dict.aug && (0, _orthos.strip)(dict.aug) == augseg && dict.plain == mainseg;
    });

    if (!maindicts.length) return;
    var flexseg = segs[4];

    var segflexes = _lodash["default"].filter(flexes, function (flex) {
      return flex.term === flexseg;
    });

    if (!segflexes.length) return;
    var cdicts = makeDictFlex(maindicts, segflexes, only);
    if (!cdicts.length) return; // log('__quads prefs3 mainseg__:', segs, mainseg, 'maindicts:', maindicts.length, '_cdicts_:', cdicts.length)

    var prefsec = {
      seg: prefseg,
      dicts: prefdicts,
      quads: true,
      pref: true
    };
    var prefsec2 = {
      seg: prefseg2,
      dicts: prefdicts2,
      pref2: true
    };
    var commonseg = [augseg, mainseg, flexseg].join('');
    var mainsec = {
      seg: commonseg,
      dicts: cdicts,
      cogns: maindicts,
      aug: augseg,
      stem: mainseg,
      flex: flexseg
    };
    var chain = [prefsec, prefsec2, mainsec];
    chains.push(chain);
  });
  chains = _lodash["default"].compact(chains);
  return chains;
}

function makeDictFlex(dicts, flexes, only) {
  var _cdicts;

  var names = _lodash["default"].filter(dicts, function (dict) {
    return dict.name && !dict.verb;
  }); // errs in some dicts


  var nflexes = _lodash["default"].filter(flexes, function (flex) {
    return flex.name;
  });

  var verbs = _lodash["default"].filter(dicts, function (dict) {
    return dict.verb && !dict.name;
  });

  var vflexes = _lodash["default"].filter(flexes, function (flex) {
    return flex.verb;
  }); // log('_____________________________________ verb-name:', dicts.length, 'verbs:', verbs.length, vflexes.length, 'names:', names.length, nflexes.length)
  // let cdicts = []


  var cdicts = (0, _mutables.parseName)(names, nflexes, only); // cdicts.push(ndicts)

  var vdicts = (0, _mutables.parseVerb)(verbs, vflexes, only);

  (_cdicts = cdicts).push.apply(_cdicts, _toConsumableArray(vdicts));

  var exacts = _lodash["default"].filter(cdicts, function (dict) {
    return !dict.possible;
  });

  if (exacts.length) cdicts = exacts; // let pdicts = parsePart(verbs, pflexes) // осторожно - εἴη дает бред
  // cdicts.push(pdicts)
  // cdicts = _.flatten(cdicts)

  return cdicts;
}

function parseAugPlain_(aplain) {
  var pfirst = _lodash["default"].first(aplain);

  var second = aplain[1]; // let third = aplain[X]

  var aug;

  if (_utils.vowels.includes(pfirst)) {
    if (_utils.uisyms.includes(second)) aug = aplain.slice(0, 2); // i.e. NO aspiration
    // else if (third == ypo) aug = aplain.slice(0,X)
    else aug = pfirst;
  }

  return aug;
} // function selectMutablePlain(seg, muts) {
//   let irregs = _.filter(muts, dict=> { return dict.irreg && dict.plain == seg })
//   let regs = _.filter(muts, dict=> { return !dict.irreg  })
//   let names = _.filter(regs, dict=> { return dict.name && dict.plain == seg})
//   let verbs = _.filter(regs, dict=> { return dict.verb })
//   let fits
//   // log('____V seg:', seg, verbs.length, 'irregs', irregs.length )
//   let aug = parseAugPlain(seg)
//   if (aug) {
//     let reaug = new RegExp('^' + aug)
//     let rplain = seg.replace(reaug, '')
//     let augdicts = _.filter(verbs, dict=> {
//       if (!dict.augs) return
//       let augs = dict.augs.map(aug=> { return strip(aug) })
//       // log('____AUG seg:', seg, dict.rdict,  'aug:', aug, 'augs:', augs )
//       return dict.plain == rplain && augs.includes(aug) && seg == [aug, dict.plain].join('')
//       // return dict.augs && augs.includes(aug) && seg == [aug, dict.plain].join('')
//     })
//     fits = augdicts
//   } else {
//     fits = _.filter(verbs, dict=> { return dict.plain == seg && !vowels.includes(comb(dict.rdict)[0]) })
//     names = _.filter(names, dict=> { return !vowels.includes(comb(dict.rdict)[0]) }) // во всех словарях должет быть dict
//   }
//   fits.push(...names)
//   fits.push(...irregs)
//   // log('____FITS seg:', seg, fits.length, 'irregs', irregs.length )
//   return fits
// }
// // MUTS:
// function selectMutable(seg, muts) {
//   let irregs = _.filter(muts, dict=> { return dict.irreg && dict.plain == seg })
//   let regs = _.filter(muts, dict=> { return !dict.irreg  })
//   let names = _.filter(regs, dict=> { return dict.name && dict.plain == seg})
//   let verbs = _.filter(regs, dict=> { return dict.verb })
//   let fits
//   // log('____V seg:', seg, muts.length, 'irregs', irregs.length )
//   let aug = parseAug(seg)
//   if (aug) {
//     let reaug = new RegExp('^' + aug)
//     let rplain = seg.replace(reaug, '')
//     let augdicts = _.filter(verbs, dict=> {
//       return dict.augs && dict.plain == rplain && dict.augs.includes(aug) && seg == [aug, dict.plain].join('')
//     })
//     fits = augdicts
//   } else {
//     fits = _.filter(verbs, dict=> { return dict.plain == seg && !vowels.includes(comb(dict.rdict)[0]) })
//     names = _.filter(names, dict=> { return !vowels.includes(comb(dict.rdict)[0]) }) // во всех словарях должет быть dict
//   }
//   fits.push(...names)
//   fits.push(...irregs)
//   // log('____END seg:', seg, fits.length, 'irregs', irregs.length )
//   // здесь exacts быть не может, они возникают позже, в parseName только // но не влияют-ли compounds?
//   let notexacts = _.filter(fits, dict=> { return dict.possible })
//   if (notexacts.length) {
//     log('_________________________ NOT EXACTS HERE', notexacts)
//     throw new Error()
//   }
//   return fits
// }
// // нужно упростить радикально
// function selectMutableNew(seg, muts) {
//   let irregs = _.filter(muts, dict=> { return dict.irreg && dict.plain == seg })
//   let regs = _.filter(muts, dict=> { return !dict.irreg  })
//   let names = _.filter(regs, dict=> { return dict.name && dict.plain == seg})
//   let verbs = _.filter(regs, dict=> { return dict.verb && dict.plain == seg })
//   verbs.push(...names)
//   verbs.push(...irregs)
//   // log('____END seg:', seg, fits.length, 'irregs', irregs.length )
//   return verbs
// }
// function parseAug (aplain) {
//   let syms = aplain.split('')
//   let inters = _.intersection(syms, asps)
//   let aug
//   if (inters.length) {
//     let aspidx = syms.indexOf(inters[0])
//     aug = syms.slice(0,aspidx+1).join('')
//   }
//   return aug
// }
// function parseAugPlain (aplain) {
//   let pfirst = _.first(aplain)
//   let second = aplain[1]
//   let uisyms = ['υ', 'ι']
//   let aug
//   if (vowels.includes(pfirst)) {
//     if (uisyms.includes(second)) aug = aplain.slice(0,2)
//     else aug = aplain.slice(0,1)
//   }
//   if (!aug) aug = ''
//   // log('_________________aplain, aug', aplain, pfirst, second, ':', aug)
//   return aug
// }
// function parseAug_WKT (aplain) {
//   let pfirst = _.first(aplain)
//   let second = aplain[1]
//   let uisyms = ['υ', 'ι']
//   let aug
//   if (vowels.includes(pfirst)) {
//     if (uisyms.includes(second)) aug = aplain.slice(0,3)
//     else if (asps.includes(second)) aug = aplain.slice(0,2) // aspiration
//     else aug = aplain.slice(0,1)
//   }
//   if (!aug) aug = ''
//   // log('_________________aplain, aug', aplain, pfirst, second, ':', aug)
//   return aug
// }
//# sourceMappingURL=chains.js.map