"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseVerb = parseVerb;
exports.parseName = parseName;

var _utils = require("./utils");

var _lodash = _interopRequireDefault(require("lodash"));

var _verbRegKeys = require("./verb-reg-keys");

var _nameRegKeys = require("./name-reg-keys");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var d = require('debug')('app');

var log = console.log; // verbs строятся по разным stems, т.е. один verb может порождать один chain по разным stems :

function parseVerb(verbs, flexes, only) {
  var vdicts = [];
  verbs.forEach(function (dict) {
    if (dict.augs) throw new Error('DICT-AUGS!'); // :NB:
    // βραχυνομένῳ - lsj - это ужас, но работает. Нужно привести в порядок    // // нужно проверить - κλίνεσθαι

    if (!dict.keys && dict.key) dict.keys = _verbRegKeys.verbkeys[dict.key] || []; // lsj, etc

    if (dict.plain == only) d('VERB-d ===========================>>>', dict.rdict, 'key:', dict.key, 'dict.keys:', dict.keys.length);

    var fls = _lodash["default"].map(flexes, function (flex) {
      // if (dict.plain == only) d('verb-flex ----------------', flex.term, flex.tense, flex.key)
      var dkey = _lodash["default"].find(dict.keys, function (dkey) {
        return dkey.key == flex.key && dkey.tense == flex.tense;
      }); // то есть если для глаголов хороший набор флексий, есть все с аугментами, то для причастий примеров склонения мало. И флексии с нужным
      // аугментом попросту нет. Возможен костыль, но тогда здесь нужны флексии прилагательных:
      // сделать только для part, -- добавить parsePart - возможно возникновение лишних результатов
      // if (!dkey) dkey = _.find(dict.keys, dkey=> { return dkey.key == flex.key })


      if (!dkey) return;
      if (dict.plain == only) d('verb-DKEY-flex ------------------------', dict.rdict, dkey, flex.key);
      var cflex; // if (flex.numcase) cflex = { tense: flex.tense, numcase: flex.numcase, gend: flex.gend, voice: flex.voice, dictpkeys: JSON.stringify(dict.pkeys), pkey: flex.pkey }

      if (flex.numcase) cflex = {
        tense: flex.tense,
        numcase: flex.numcase,
        gend: flex.gend
      };else if (flex.numper) cflex = {
        tense: flex.tense,
        numper: flex.numper // else if (flex.numper) cflex = { tense: flex.tense, numper: flex.numper, dictpkeys: JSON.stringify(dict.vkeys), pkey: flex.vkey }
        // else  cflex = { tense: flex.tense, adv: flex.adv }

      };
      return cflex;
    });

    fls = _lodash["default"].compact(fls); // map, not filter!

    if (dict.plain == only) d('NC-FLS =========>>>', dict.rdict, fls.length);
    if (!fls.length) return;
    var cfls = [];
    var keyfls = {};

    _lodash["default"].flatten(fls).forEach(function (flex) {
      var keyflex = JSON.stringify(flex);
      if (keyfls[keyflex]) return;
      cfls.push(flex);
      keyfls[keyflex] = true;
    });

    dict.fls = cfls; // d('______________________>>>', dict.rdict)

    vdicts.push(dict);
  });
  return vdicts;
} // NAME


function parseName(names, flexes, only) {
  var ndicts = []; // let nnames = _.filter(names, dict => { return dict.name })
  // let nflexes = _.filter(flexes, flex => { return flex.name })

  names.forEach(function (dict) {
    // log('_________________________________________________________________________D', dict.rdict, dict.plain)
    if (dict.plain == only) d('NAME-d ===========================>>>', dict.rdict);
    /*
      key - проверяется, но не обязательно. Сколько плохих значений возникнет?
      или - сделать это только в компаундах? Где меняется ударение, и правильная флексия может отсутствовать. И вообще меняется склонение
    */
    // if (dict.key && !dict.keys) dict.keys = namekeys[dict.key]
    // if (dict.key && !dict.keys) log('_________________________________')

    var fls = _lodash["default"].filter(flexes, function (flex) {
      // if (dict.plain == only) log('NAME-f -------------->', flex)
      var fkey = flex.key.split('-')[0]; // if (!dict.gends && dict.key && dict.key != fkey) return false

      if (!dict.gends && dict.key && dict.key != flex.key && dict.key != fkey) return false; // corr. - στατικός

      if (dict.gends && !dict.gends.includes(flex.gend)) return false; // if (flex.adv) dict.pos = 'adv'
      // это неясно, правильно ли, т.е. всегда ли, на все ли dict нужно навесить pos=adv

      return true;
    });

    if (dict.plain == only) d('NAME-flex.size ===========================>>>', fls.length);
    if (!fls.length) return; // непонятно, как избавиться от лишних значений adj в ἡμισέως, т.е. adv: - или пропадет значение при совпадении adv и adj?

    var advfls = _lodash["default"].filter(fls, function (fl) {
      return fl.adv;
    }); // if (advfls.length) fls = advfls
    // добавить в dict и потом отбросить лишние dicts, если есть exacts


    var exactfls;
    var ksize = dict.key.split('-').length;
    var keys;
    if (ksize == 1) keys = _nameRegKeys.namekeys[dict.key], exactfls = _lodash["default"].filter(fls, function (flex) {
      return keys.includes(flex.key);
    });else exactfls = _lodash["default"].filter(fls, function (flex) {
      return dict.key == flex.key;
    }); // log('__KEYS', dict.key, dict.keys)

    if (!exactfls.length && dict.plain.length < 3) return; // плохие значения от одной буквы в стеме, типа ἰσθμός = ἰσθ + μ

    if (exactfls.length) fls = exactfls;else dict.possible = true;
    dict.fls = compactNameFls(fls, exactfls.length);
    ndicts.push(dict); // log('___ DICT', dict.rdict, dict.fls.length)
  }); // log('___________________ EXDICTS', ndicts.length)

  var exdicts = _lodash["default"].filter(ndicts, function (dict) {
    return !dict.possible;
  });

  if (exdicts) ndicts = exdicts; // log('________________ NDICTS', ndicts.length)

  return ndicts;
}

function compactNameFls(fls, exact) {
  var cleanfls = [];
  var flkey = {};
  fls.forEach(function (flex) {
    var clflex; // if (flex.adv) clflex = { adv: true, term: flex.term, degree: flex.degree } // только для тестов
    // else clflex = { name: true, term: flex.term, numcase: flex.numcase }

    if (flex.adv) clflex = {
      degree: flex.degree
    };else clflex = {
      numcase: flex.numcase
    };
    if (flex.gend) clflex.gend = flex.gend;
    if (!exact) clflex.possible = true;
    var flexkey = [clflex.gend, clflex.numcase].join('-');
    if (flkey[flexkey]) return;
    cleanfls.push(clflex);
    flkey[flexkey] = true;
  });
  return cleanfls;
} // export function parsePart_ (verbs, flexes) {
// }
//# sourceMappingURL=mutables.js.map