"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.stressed = stressed;
exports.dbg = dbg;
exports.insp = insp;
exports.mood = exports.voice = exports.time = exports.apicompats = exports.augmods = exports.affixes = exports.strongs = exports.weaks = exports.eaug = exports.contrs = exports.mutes = exports.stresses = exports.corvowels = exports.vowels = exports.coronis = exports.uisyms = exports.ypo = exports.aspirations = exports.tobedel = exports.accents = void 0;

var _lodash = _interopRequireDefault(require("lodash"));

var _ac, _weaks, _strongs, _affixes;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

//
var util = require('util');

var ac = (_ac = {
  'oxia': "\u0301",
  'varia_': "`",
  'varia': "\u0300",
  'peris': "\u0342",
  '': '',
  'psili': "\u0313",
  'dasia': "\u0314"
}, _defineProperty(_ac, "", ''), _defineProperty(_ac, "", ''), _ac);
var accents = ac;
exports.accents = accents;
var tobedel = [ac.varia, ac.oxia, ac.peris]; // dialitika remains // ac.dasia, , ac.ypo // , ac.psili

exports.tobedel = tobedel;
var aspirations = {
  'psili': "\u0313",
  'dasia': "\u0314"
};
exports.aspirations = aspirations;
var ypo = "\u0345";
exports.ypo = ypo;
var uisyms = ['υ', 'ι'];
exports.uisyms = uisyms;
var coronis = "\u1FBD";
exports.coronis = coronis;
var vowels = ['α', 'ε', 'ι', 'ο', 'ω', 'η', 'υ']; // export const vowels =  ['α', 'ε', 'ι', 'ο', 'ω', 'η', 'υ', 'ͅ'] // ypo last

exports.vowels = vowels;
var corvowels = ['α', 'ε', 'ι', 'ο']; // vows replaced by coronis

exports.corvowels = corvowels;
var stresses = [ac.oxia, ac.varia, ac.peris];
exports.stresses = stresses;

function stressed(str) {
  var syms = str.split(''); // let stress
  // syms.forEach(sym => {
  //   if (stresses.includes(sym)) stress = sym
  // })

  return _lodash["default"].intersection(syms, stresses).length;
}

var mutes = function mutes() {
  return ['ψ', 'ξ'];
}; // export const vowels =
// () => ['α', 'ε', 'ι', 'ο', 'ω', 'η', 'υ']


exports.mutes = mutes;
var contrs = {
  'ew': ['ε', ac.oxia, 'ω'].join(''),
  'aw': ['α', ac.oxia, 'ω'].join(''),
  'ow': ['ο', ac.oxia, 'ω'].join('') // export const eaug = 'ἐ'

};
exports.contrs = contrs;
var eaug = 'ε'; // ᾔνουν - αἰνέω
// export const weaks = {'η': 'α', 'ω': 'ο', 'ῃ': 'ᾳ', '': '', '': ''}

exports.eaug = eaug;
var weaks = (_weaks = {
  'α': ['η'],
  'αι': ['ῃ'],
  'ανα': ['ανε', 'ανη'],
  'αν': ['ανε'],
  'απα': ['απη'],
  // 'αστ': ['ανεστ'],
  'απαι': ['απῃ'],
  'απε': ['απει'],
  'απο': ['απε', 'απω'],
  'αφαι': ['αφῃ'],
  'αφο': ['αφω'],
  'αρα': ['ηρα'],
  'ε': ['η'],
  'δια': ['διε', 'διη'],
  'διε': ['διη'],
  'διαι': ['διῃ'],
  'εισε': ['ειση'],
  'εκ': ['εξε'],
  'εκρ': ['εξερρ'],
  'εξα': ['εξη'],
  'εξε': ['εξη'],
  'εν': ['ενε'],
  'επεν': ['επενε'],
  'εμ': ['ενε'],
  'επα': ['επη'],
  'επαι': ['επῃ'],
  'επι': ['επε', 'επει'],
  'επε': ['επι', 'επη'],
  'επο': ['επω'],
  'ευα': ['ευη'],
  'η': ['ε'],
  // ηὗρον
  'κατα': ['κατε', 'κατη'],
  'κατοι': ['κατῳ'],
  'μετα': ['μετε'],
  'ο': ['ω'],
  'οι': ['ῳ'],
  'παρα': ['παρε'],
  'παρε': ['παρη'],
  'περι': ['περιε'],
  'περιε': ['περιη'],
  'προσ': ['προσε'],
  'προσα': ['προση'],
  'προσε': ['προση', 'προσ'],
  'προ': ['προε'],
  'ρ': ['ερρ'],
  'συνε': ['συνη', 'συνει', 'συγ', 'συλ', 'συμ'],
  'συλ': ['συνε'],
  'συμ': ['συνε'],
  'συσ': ['συνε'],
  'συγ': ['συνε'],
  'συνη': ['συνα'],
  // συνήγαγον - συναγόγον - to fake
  'υπα': ['υπη'],
  'υπο': ['υπε'],
  '': ['']
}, _defineProperty(_weaks, "", ['']), _defineProperty(_weaks, "", ['']), _defineProperty(_weaks, "", ['']), _defineProperty(_weaks, "", ['']), _defineProperty(_weaks, "", ['']), _defineProperty(_weaks, "", ['']), _defineProperty(_weaks, "", ['']), _defineProperty(_weaks, "", ['']), _weaks);
exports.weaks = weaks;
var strongs = (_strongs = {
  'η': 'α',
  'ω': 'ο',
  'ᾐ': 'αι',
  '': ''
}, _defineProperty(_strongs, "", ''), _defineProperty(_strongs, "", ''), _strongs);
exports.strongs = strongs;
var affixes = (_affixes = {
  'διε': 'δια',
  'διῃ': 'διαι',
  'διη': 'δια',
  'διῳ': 'διοι',
  'εξε': 'εκ',
  'εξερρ': 'εκρ',
  'εξεκ': 'εκ',
  '': ''
}, _defineProperty(_affixes, "", ''), _defineProperty(_affixes, "", ''), _affixes); // ᾀδοίτην
// // εἰ
// export const apiaugs = [
//   ['α', ac.psili].join(''),
//   ['α', ac.dasia].join(''),
//   ['αι', ac.psili].join(''),
//   ['αι', ac.dasia].join(''),
//   ['αυ', ac.psili].join(''),
//   ['αυ', ac.dasia].join(''),
//   ['ε', ac.psili].join(''),
//   ['ε', ac.dasia].join(''),
//   ['ει', ac.psili].join(''),
//   ['ει', ac.dasia].join(''),
//   ['ευ', ac.psili].join(''),
//   ['ευ', ac.dasia].join(''),
//   ['ο', ac.psili].join(''),
//   ['ο', ac.dasia].join(''),
//   ['οι', ac.psili].join(''),
//   ['οι', ac.dasia].join(''),
//   ['ου', ac.psili].join(''),
//   ['ου', ac.dasia].join(''),
//   ['ι', ac.psili].join(''),
//   ['ι', ac.dasia].join(''),
//   ['υ', ac.psili].join(''),
//   ['υ', ac.dasia].join(''),
//   ['ω', ac.psili].join(''),
//   ['ω', ac.dasia].join(''),
//   ['η', ac.psili].join(''),
//   ['η', ac.psili, ac.ypo].join(''),
//   ['η', ac.dasia].join(''),
//   // ['', ac.psili].join(''),
//   // ['', ac.dasia].join(''),
//   // ['', ac.psili].join(''),
//   // ['', ac.dasia].join('')
//     ]
// export const augs = {
//   'X̓': 'ἐ',
//   'ἀ': 'ἀ ἠ',
//   'ἠ': 'ἠ ἀ',
//   'ἡ': 'ἡ',
//   'ὁ': 'ὁ ὡ',
//   'ὡ': 'ὁ ὡ',
//   'ᾐ': 'αἰ'
// }
// export const augplains = {
//   'ε': 'X',
//   'α': 'α η',
//   'η': 'η',
//   'ο': 'ο ω'
// }
// export const augs_ = [
//   ['ω', ac.psili].join(''),
//   ['ω', ac.dasia].join(''),
//   ['η', ac.psili].join(''),
//   ['η', ac.psili, ac.ypo].join(''),
//   ['η', ac.dasia].join(''),
//   // ['', ac.psili].join(''),
//   // ['', ac.dasia].join(''),
//   // ['', ac.psili].join(''),
//   // ['', ac.dasia].join('')
// ]

exports.affixes = affixes;
var augmods = ['act.impf.ind', 'mp.impf.ind', 'act.aor.ind', 'mid.aor.ind', 'act.ppf.ind', 'mp.ppf.ind', 'pas.aor.ind']; //
// mp.pf.ind - στέλλω - ἔσταλμαι - has augment, exeption

exports.augmods = augmods;
var apicompats = ['act.pres.ind', 'act.fut.ind', 'act.impf.ind', 'mp.pres.ind', 'mp.impf.ind', 'act.pres.sub', 'mp.pres.sub', 'mp.pres.opt', 'act.pres.opt', 'act.pres.imp', 'mp.pres.imp', 'mid.fut.ind', 'act.fut.opt', 'mid.fut.opt', 'act.aor.ind', 'mid.aor.ind', 'act.aor.sub', 'mid.aor.sub', 'act.aor.opt', 'mid.aor.opt', 'act.aor.imp', 'mid.aor.imp', 'pas.aor.ind', 'pas.fut.ind', 'pas.fut.opt', 'pas.aor.sub', '', '', ''];
exports.apicompats = apicompats;

var time = function time(vrnt) {
  return vrnt.split('.')[1];
};

exports.time = time;

var voice = function voice(vrnt) {
  return vrnt.split('.')[0];
};

exports.voice = voice;

var mood = function mood(vrnt) {
  return vrnt.split('.')[2];
}; // export const startWith =
// (str) => { return vrnt.split('.')[2] }


exports.mood = mood;
var print = process.argv.slice(3)[0]; // if (process.env.NODE_ENV === 'test')

function dbg() {
  if (print == 'log') console.log.apply(console, arguments);
}

function insp() {
  if (print != 'insp') return;

  var vs = _lodash["default"].values(arguments);

  if (vs.length === 1) vs = vs[0]; // console.log(util.inspect(vs, {showHidden: false, depth: null}))
  // console.log(util.inspect(vs, {showHidden: false, depth: true}))

  console.log(util.inspect(vs, false, null, true));
}
//# sourceMappingURL=utils.js.map